@@ -1,6 +1,6 @@
 /**
  * Python plugin for Orthanc
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2020-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -19,7 +19,7 @@
 
 #pragma once
 
-#include <Python.h>
+#include "../PythonHeaderWrapper.h"
 
 void RegisterOrthancSdk(PyObject* module);
 PyMethodDef* GetOrthancSdkFunctions();
@@ -27,9 +27,10 @@ PyMethodDef* GetOrthancSdkFunctions();
 PyObject* GetOrthancPluginRestOutputType();
 PyObject* GetOrthancPluginServerChunkedRequestReaderType();
 PyObject* GetOrthancPluginImageType();
+PyObject* GetOrthancPluginJobType();
 PyObject* GetOrthancPluginWorklistQueryType();
 PyObject* GetOrthancPluginStorageAreaType();
-PyObject* GetOrthancPluginJobType();
+PyObject* GetOrthancPluginFindMatcherType();
 PyObject* GetOrthancPluginDicomWebNodeType();
 PyObject* GetOrthancPluginWorklistAnswersType();
 PyObject* GetOrthancPluginFindAnswersType();
