@@ -1,6 +1,6 @@
 /**
  * Python plugin for Orthanc
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2020-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -19,9 +19,11 @@
 
 #include "OnChangeCallback.h"
 
-#include "PythonObject.h"
+#include "PythonString.h"
 
-#include <OrthancPluginCppWrapper.h>
+#include "../Resources/Orthanc/Plugins/OrthancPluginCppWrapper.h"
+
+#include <Compatibility.h>  // For std::unique_ptr<>
 
 #include <boost/thread.hpp>
 
@@ -68,6 +70,8 @@ public:
 
 
 
+// This corresponds to a simplified, standalone version of
+// "Orthanc::SharedMessageQueue" from the Orthanc framework
 class PendingChanges : public boost::noncopyable
 {
 private:
@@ -116,7 +120,7 @@ public:
       }
     }
 
-    std::auto_ptr<PendingChange> change(queue_.front());
+    std::unique_ptr<PendingChange> change(queue_.front());
     queue_.pop_front();
 
     return change.release();
@@ -131,6 +135,17 @@ static boost::thread   changesThread_;
 static PyObject*       changesCallback_ = NULL;
 
 
+static void StopThread()
+{
+  stopping_ = true;
+
+  if (changesThread_.joinable())
+  {
+    changesThread_.join();
+  }
+}
+
+
 static void ChangesWorker()
 {
   while (!stopping_)
@@ -147,10 +162,14 @@ static void ChangesWorker()
         try
         {
           PythonLock lock;
+
+          PythonString resourceId(lock, change->GetResourceId());
+          
           PythonObject args(lock, PyTuple_New(3));
           PyTuple_SetItem(args.GetPyObject(), 0, PyLong_FromLong(change->GetChangeType()));
           PyTuple_SetItem(args.GetPyObject(), 1, PyLong_FromLong(change->GetResourceType()));
-          PyTuple_SetItem(args.GetPyObject(), 2, PyUnicode_FromString(change->GetResourceId().c_str()));
+          PyTuple_SetItem(args.GetPyObject(), 2, resourceId.Release());
+          
           PythonObject result(lock, PyObject_CallObject(changesCallback_, args.GetPyObject()));
 
           std::string traceback;
@@ -175,9 +194,11 @@ static OrthancPluginErrorCode OnChangeCallback(OrthancPluginChangeType changeTyp
                                                OrthancPluginResourceType resourceType,
                                                const char* resourceId)
 {
+  pendingChanges_.Enqueue(changeType, resourceType, resourceId);
+
+  if (changeType == OrthancPluginChangeType_OrthancStopped)
   {
-    PythonLock lock;
-    pendingChanges_.Enqueue(changeType, resourceType, resourceId);
+    StopThread();
   }
   
   return OrthancPluginErrorCode_Success;
@@ -223,12 +244,7 @@ PyObject* RegisterOnChangeCallback(PyObject* module, PyObject* args)
 
 void FinalizeOnChangeCallback()
 {
-  stopping_ = true;
-
-  if (changesThread_.joinable())
-  {
-    changesThread_.join();
-  }
+  StopThread();
 
   {
     PythonLock lock;
