@@ -1,6 +1,6 @@
 /**
  * Python plugin for Orthanc
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2020-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -19,7 +19,7 @@
 
 #pragma once
 
-#include <Python.h>
+#include "PythonHeaderWrapper.h"
 
 void FinalizeOnChangeCallback();
 
