@@ -1,6 +1,6 @@
 /**
- * Python plugin for Orthanc
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+2 * Python plugin for Orthanc
+ * Copyright (C) 2020-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -19,9 +19,10 @@
 
 #pragma once
 
-#include "../Resources/Orthanc/Core/Compatibility.h"
 #include "PythonObject.h"
 
+#include <Compatibility.h>
+
 #include <memory>
 
 class PythonModule : public boost::noncopyable
