@@ -1,6 +1,6 @@
 /**
  * Python plugin for Orthanc
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2020-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -21,18 +21,30 @@
 
 #include "PythonObject.h"
 
+#include <Compatibility.h>  // For std::unique_ptr
+
 // A Python string is always valid, or an exception was thrown on its creation
 class PythonString : public boost::noncopyable
 {
 private:
-  PythonObject  string_;
+  std::unique_ptr<PythonObject>  string_;
+
+  void SanityCheck();
 
 public:
   PythonString(PythonLock& lock,
                const std::string& utf8);
 
+  PythonString(PythonLock& lock,
+               const char* utf8);
+
   PyObject* GetPyObject() const
   {
-    return string_.GetPyObject();
+    return string_->GetPyObject();
+  }
+
+  PyObject* Release()
+  {
+    return string_->Release();
   }
 };
